@@ -15,17 +15,20 @@ from futurehouse_client.models.app import (
 )
 from futurehouse_client.models.data_storage_methods import (
     DataContentType,
+    DataStorageEntryPermittedAccessors,
     DataStorageLocationPayload,
+    DataStorageShareStatus,
     DataStorageType,
     RawFetchResponse,
 )
 from futurehouse_client.models.rest import (
-    FilterLogic,
+    # FilterLogic,
     SearchCriterion,
     SearchOperator,
 )
 
 ADMIN_API_KEY = os.environ["PLAYWRIGHT_ADMIN_API_KEY"]
+PUBLIC_API_KEY = os.environ.get("PLAYWRIGHT_PUBLIC_API_KEY", "")
 
 
 @pytest.fixture(name="admin_client")
@@ -37,6 +40,15 @@ def fixture_admin_client():
     )
 
 
+@pytest.fixture(name="pub_client")
+def fixture_pub_client():
+    """Create a RestClient for testing; using a public user key with limited access."""
+    return RestClient(
+        stage=Stage.DEV,
+        api_key=PUBLIC_API_KEY,
+    )
+
+
 @pytest.mark.timeout(300)
 def test_store_raw_content_sync(admin_client: RestClient):
     test_content = "This is random content for the sync test"
@@ -617,58 +629,161 @@ class TestDataStorageSearch:
         assert len(results) == 5
         assert test_query.lower() in results[0]["name"].lower()
 
+    # @pytest.mark.timeout(300)
+    # @pytest.mark.asyncio
+    # async def test_complex_data_storage_search_async(self, admin_client: RestClient):
+    #     test_query = "test"
+
+    #     name_test_criteria = SearchCriterion(
+    #         field="name", operator=SearchOperator.CONTAINS, value=test_query
+    #     )
+
+    #     user_id_test_criteria = SearchCriterion(
+    #         field="user_id",
+    #         operator=SearchOperator.EQUALS,
+    #         value="a5E0sDbOYEWLBoy9qzOQ8yfKiKw1",
+    #     )
+
+    #     dataset_id_test_criteria = SearchCriterion(
+    #         field="dataset_id",
+    #         operator=SearchOperator.EQUALS,
+    #         value="8bb27d71-8ec6-4845-a09e-4eceefb38cba",
+    #     )
+
+    #     description_test_criteria = SearchCriterion(
+    #         field="description",
+    #         operator=SearchOperator.CONTAINS,
+    #         value="xyz.api.futurehouse.org",
+    #     )
+
+    #     or_results = await admin_client.asearch_data_storage(
+    #         criteria=[
+    #             name_test_criteria,
+    #             user_id_test_criteria,
+    #             dataset_id_test_criteria,
+    #             description_test_criteria,
+    #         ],
+    #         filter_logic=FilterLogic.OR,
+    #     )
+
+    #     and_results = await admin_client.asearch_data_storage(
+    #         criteria=[
+    #             name_test_criteria,
+    #             user_id_test_criteria,
+    #             dataset_id_test_criteria,
+    #             description_test_criteria,
+    #         ],
+    #         filter_logic=FilterLogic.AND,
+    #     )
+
+    #     assert or_results is not None
+    #     assert len(or_results) > 0
+
+    #     assert and_results is not None
+    #     assert len(and_results) > 0
+    #     assert test_query.lower() in and_results[0]["name"].lower()
+
+    #     assert len(or_results) > len(and_results)
+
+
+class TestEntryPermissions:
+    @pytest.mark.timeout(300)
+    def test_data_update_entry_permissions_sync(
+        self, admin_client: RestClient, pub_client: RestClient
+    ):
+        test_content = "This is random content for the sync test"
+
+        # Store the text content
+        create_entry_response = admin_client.store_text_content(
+            name=f"E2E test entry text: {uuid4()}",
+            content=test_content,
+            description="Here is some description",
+        )
+
+        assert (
+            create_entry_response.data_storage.share_status
+            == DataStorageShareStatus.PRIVATE
+        )
+
+        with pytest.raises(DataStorageError, match="Data storage entry not found"):
+            pub_client.fetch_data_from_storage(create_entry_response.data_storage.id)
+
+        update_entry_response = admin_client.update_entry_permissions(
+            data_storage_id=create_entry_response.data_storage.id,
+            share_status=DataStorageShareStatus.PUBLIC,
+            permitted_accessors=DataStorageEntryPermittedAccessors(
+                users=[],
+                organizations=[],
+            ),
+        )
+
+        assert (
+            update_entry_response.data_storage.share_status
+            == DataStorageShareStatus.PUBLIC
+        )
+
+        fetch_entry_response = admin_client.fetch_data_from_storage(
+            create_entry_response.data_storage.id
+        )
+
+        assert isinstance(fetch_entry_response, RawFetchResponse)
+        assert fetch_entry_response.content == test_content
+        assert fetch_entry_response.entry_id == create_entry_response.data_storage.id
+        assert (
+            fetch_entry_response.entry_name == create_entry_response.data_storage.name
+        )
+
+        admin_client.delete_data_storage_entry(create_entry_response.data_storage.id)
+
     @pytest.mark.timeout(300)
     @pytest.mark.asyncio
-    async def test_complex_data_storage_search_async(self, admin_client: RestClient):
-        test_query = "test"
+    async def test_data_update_entry_permissions_async(
+        self, admin_client: RestClient, pub_client: RestClient
+    ):
+        test_content = "This is random content for the async test"
 
-        name_test_criteria = SearchCriterion(
-            field="name", operator=SearchOperator.CONTAINS, value=test_query
+        # Store the text content
+        create_entry_response = await admin_client.astore_text_content(
+            name=f"E2E test entry text: {uuid4()}",
+            content=test_content,
+            description="Here is some description",
         )
 
-        user_id_test_criteria = SearchCriterion(
-            field="user_id",
-            operator=SearchOperator.EQUALS,
-            value="a5E0sDbOYEWLBoy9qzOQ8yfKiKw1",
+        assert (
+            create_entry_response.data_storage.share_status
+            == DataStorageShareStatus.PRIVATE
         )
 
-        dataset_id_test_criteria = SearchCriterion(
-            field="dataset_id",
-            operator=SearchOperator.EQUALS,
-            value="8bb27d71-8ec6-4845-a09e-4eceefb38cba",
+        with pytest.raises(DataStorageError, match="Data storage entry not found"):
+            await pub_client.afetch_data_from_storage(
+                create_entry_response.data_storage.id
+            )
+
+        update_entry_response = await admin_client.aupdate_entry_permissions(
+            data_storage_id=create_entry_response.data_storage.id,
+            share_status=DataStorageShareStatus.PUBLIC,
+            permitted_accessors=DataStorageEntryPermittedAccessors(
+                users=[],
+                organizations=[],
+            ),
         )
 
-        description_test_criteria = SearchCriterion(
-            field="description",
-            operator=SearchOperator.CONTAINS,
-            value="xyz.api.futurehouse.org",
+        fetch_entry_response = await pub_client.afetch_data_from_storage(
+            create_entry_response.data_storage.id
         )
 
-        or_results = await admin_client.asearch_data_storage(
-            criteria=[
-                name_test_criteria,
-                user_id_test_criteria,
-                dataset_id_test_criteria,
-                description_test_criteria,
-            ],
-            filter_logic=FilterLogic.OR,
+        assert isinstance(fetch_entry_response, RawFetchResponse)
+        assert fetch_entry_response.content == test_content
+        assert fetch_entry_response.entry_id == create_entry_response.data_storage.id
+        assert (
+            fetch_entry_response.entry_name == create_entry_response.data_storage.name
         )
 
-        and_results = await admin_client.asearch_data_storage(
-            criteria=[
-                name_test_criteria,
-                user_id_test_criteria,
-                dataset_id_test_criteria,
-                description_test_criteria,
-            ],
-            filter_logic=FilterLogic.AND,
+        assert (
+            update_entry_response.data_storage.share_status
+            == DataStorageShareStatus.PUBLIC
         )
 
-        assert or_results is not None
-        assert len(or_results) > 0
-
-        assert and_results is not None
-        assert len(and_results) > 0
-        assert test_query.lower() in and_results[0]["name"].lower()
-
-        assert len(or_results) > len(and_results)
+        await admin_client.adelete_data_storage_entry(
+            create_entry_response.data_storage.id
+        )
